"""create tasks table

Revision ID: 0001
Revises: 
Create Date: 2023-08-01

"""
from alembic import op
import sqlalchemy as sa
from sqlalchemy.sql import func


# revision identifiers, used by Alembic.
revision = '0001'
down_revision = None
branch_labels = None
depends_on = None


def upgrade() -> None:
    op.create_table(
        'tasks',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('title', sa.String(255), nullable=False, index=True),
        sa.Column('description', sa.Text(), nullable=True),
        sa.Column('status', sa.Enum('todo', 'in_progress', 'done', name='taskstatus'), 
                 nullable=False, default='todo', index=True),
        sa.Column('priority', sa.Enum('low', 'medium', 'high', name='taskpriority'), 
                 nullable=False, default='medium', index=True),
        sa.Column('due_date', sa.DateTime(), nullable=True),
        sa.Column('completed', sa.Boolean(), nullable=False, default=False, index=True),
        sa.Column('created_at', sa.DateTime(), nullable=False, default=func.now()),
        sa.Column('updated_at', sa.DateTime(), nullable=False, default=func.now(), onupdate=func.now()),
        sa.PrimaryKeyConstraint('id'),
    )
    op.create_index('ix_tasks_id', 'tasks', ['id'])


def downgrade() -> None:
    op.drop_index('ix_tasks_id', 'tasks')
    op.drop_table('tasks')